@@ -10,6 +10,7 @@ URL_ENDPOINT = {
     'LOGIN': {
         'INDEX': '/xtgl/login_slogin.html',
         'CAPTCHA': '/zfcaptchaLogin',
+        'KCAPTCHA': '/kaptcha',
         'PUBLIC_KEY': '/xtgl/login_getPublicKey.html',
     },
     "SCORE_URL": "",
@@ -19,5 +20,8 @@ URL_ENDPOINT = {
     },
     'SCORE': {
         'API': '/cjcx/cjcx_cxDgXscj.html'
+    },
+    'INFO': {
+        'API': '/xsxxxggl/xsgrxxwh_cxXsgrxx.html'
     }
 }
