@@ -6,7 +6,7 @@
     :date: 2021/09/20 11:11:54
 '''
 
-from os import name, path
+from os import path
 from setuptools import setup, find_packages
 
 basedir = path.abspath(path.dirname(__file__))
@@ -18,7 +18,7 @@ with open(path.join(basedir, "README.md"), encoding='utf-8') as f:
 setup(
     name="zf-school-sdk",
     author="farmer.chillax",
-    version="1.1.1",
+    version="1.3.7",
     license='MIT',
     author_email="farmer-chong@qq.com",
     description="zf School SDK for Python",
@@ -26,7 +26,8 @@ setup(
     long_description_content_type='text/markdown',
     url='https://github.com/Farmer-chong/new-school-sdk',
     packages=find_packages(),
-    package_data={},
+    # package_data={},
+    package_data={"school_sdk": ['check_code/model.pkl']},
     include_package_data=True,
     platforms='any',
     zip_safe=False,
@@ -36,14 +37,16 @@ setup(
         'pyquery',
         'bs4',
         'Pillow',
-        'fake-headers'
+        'fake-headers',
+        'torch',
+        'torchvision',
     ],
     classifiers=[
         'Environment :: Web Environment',
         'Intended Audience :: Developers',
         'License :: OSI Approved :: MIT License',
         'Operating System :: OS Independent',
-        'Programming Language :: Python :: 3.6',
+        'Programming Language :: Python :: 3.8',
         'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
         'Topic :: Software Development :: Libraries :: Python Modules'
     ]
